@@ -10,7 +10,8 @@ my $scanner = new Nmap::Scanner;
 
 $scanner->protocol_scan();
 $scanner->debug(1);
-$scanner->add_target($ARGV[0] || 'localhost');
+$scanner->add_target($ARGV[0] || 
+                         die "Missing host to scan!\n$0 host\n");
 my $results = $scanner->scan();
 
 print $results->as_xml();
