@@ -24,6 +24,7 @@ sub new {
         SERVICE    => '', 
         VERSION    => '', 
         EXTRAINFO  => '', 
+        TUNNEL     => '', 
         CONF       => ''};
     return bless $me, $class;
 }
@@ -100,6 +101,16 @@ sub conf {
 
 =pod
 
+=head2 tunnel()
+
+=cut
+
+sub tunnel {
+    (defined $_[1]) ? ($_[0]->{TUNNEL} = $_[1]) : return $_[0]->{TUNNEL};
+}
+
+=pod
+
 =head1 VERSION SCANNING MUTATORS
 
 Information will be present for this only if -sV is used.
